@@ -41,25 +41,30 @@
 #' @param computeError should the error be computed in every iteration?
 #' @param inputsTest a matrix with inputs to test the network
 #' @param targetsTest the corresponding targets for the test input
+#' @param pruneFunc the pruning function to use
+#' @param pruneFuncParams the parameters for the pruning function. Unlike the other functions, 
+#' these have to be given in a named list. See the pruning demos for further explanation. 
 #' @return a list containing:
 #' \item{fitValues}{the fitted values, i.e. outputs of the training inputs}
 #' \item{IterativeFitError}{The SSE in every iteration/epoch on the training set}
 #' \item{testValues}{the predicted values, i.e. outputs of the test inputs}
 #' \item{IterativeTestError}{The SSE in every iteration/epoch on the test set}
-#' @rdname SnnsRObject$train
+#' @rdname SnnsRObject-train
+#' @name SnnsRObject$train
 #' @usage \S4method{train}{SnnsR}(inputsTrain, targetsTrain=NULL, 
 #'     initFunc="Randomize_Weights", initFuncParams=c(1.0, -1.0), 
 #'     learnFunc="Std_Backpropagation", learnFuncParams=c(0.2, 0),
 #'     updateFunc="Topological_Order", updateFuncParams=c(0.0), 
 #'     outputMethod="reg_class", maxit=100, shufflePatterns=TRUE, 
-#'     computeError=TRUE, inputsTest=NULL, targetsTest=NULL)
-#' @aliases train,SnnsR-method SnnsRObject$train
+#'     computeError=TRUE, inputsTest=NULL, targetsTest=NULL,
+#'     pruneFunc=NULL, pruneFuncParams=NULL)
+#' @aliases train,SnnsR-method SnnsR__train
 SnnsR__train <- function(snnsObject, inputsTrain, targetsTrain=NULL, 
     initFunc="Randomize_Weights", initFuncParams=c(1.0, -1.0), 
     learnFunc="Std_Backpropagation", learnFuncParams=c(0.2, 0),
     updateFunc="Topological_Order", updateFuncParams=c(0.0), outputMethod="reg_class", 
     maxit=100, shufflePatterns=TRUE, computeError=TRUE, inputsTest=NULL, targetsTest=NULL, 
-    serializeTrainedObject=TRUE) {
+    serializeTrainedObject=TRUE, pruneFunc=NULL, pruneFuncParams=NULL) {
 
   testing <- TRUE
   if(is.null(inputsTest)) testing <- FALSE
@@ -78,8 +83,16 @@ SnnsR__train <- function(snnsObject, inputsTrain, targetsTrain=NULL,
   expandedUpdateFuncParams <- c(0,0,0,0,0)
   for(i in 1:length(updateFuncParams)) expandedUpdateFuncParams[i] <- updateFuncParams[i]
   
-  
-  snnsObject$setLearnFunc(learnFunc)
+  if(is.null(pruneFunc)) {
+    snnsObject$setLearnFunc(learnFunc)
+  } else {
+    snnsObject$setFFLearnFunc(learnFunc)
+    snnsObject$setPrunFunc(pruneFunc)
+    computeError <- TRUE
+  }
+
+
+
   snnsObject$setUpdateFunc(updateFunc)
   
   patSetTrain <- NULL
@@ -116,7 +129,13 @@ SnnsR__train <- function(snnsObject, inputsTrain, targetsTrain=NULL,
   
   for(i in 1:maxit) {
   
-    res <- snnsObject$learnAllPatterns(expandedLearnFuncParams)
+    res <- NULL
+    if(is.null(pruneFunc)) {
+      res <- snnsObject$learnAllPatterns(expandedLearnFuncParams)
+    } else {
+      res <- snnsObject$learnAllPatternsFF(expandedLearnFuncParams)
+    }
+
     #if(res[[1]] != 0) print(paste("An error occured at iteration ", i, " : ", res, sep=""))
     if(computeError)
       errorTrain[i] <- res[[2]]
@@ -142,6 +161,68 @@ SnnsR__train <- function(snnsObject, inputsTrain, targetsTrain=NULL,
     
   }
   
+#-----------------------------------------------------
+# pruning 
+  
+  if(!is.null(pruneFunc)) {
+    
+    #TODO error handling if parameters are not there.
+    max_pr_error_increase <- pruneFuncParams$max_pr_error_increase
+    pr_accepted_error <- pruneFuncParams$pr_accepted_error
+    #pr_recreate <- TRUE
+    no_of_pr_retrain_cycles <- pruneFuncParams$no_of_pr_retrain_cycles
+    min_error_to_stop <- pruneFuncParams$min_error_to_stop
+    init_matrix_value <- pruneFuncParams$init_matrix_value
+    input_pruning <- pruneFuncParams$input_pruning
+    hidden_pruning <- pruneFuncParams$hidden_pruning
+    
+    first_error <- errorTrain[maxit]
+
+    # maximum error
+    max_error = first_error * (1 + max_pr_error_increase / 100);
+    if(max_error < pr_accepted_error)
+      max_error = pr_accepted_error
+    
+    PR_ALL_PATTERNS <- -1
+    net_error <- vector()
+    retrain_loop_count <- 0
+    
+    # pruning until net error <= maximum error
+    repeat {
+      
+      # delete some weights
+      pr_res <- snnsObject$callPrunFunc(PR_ALL_PATTERNS)
+      
+      # calculate net error
+      pr_res <- snnsObject$calcMeanDeviation(PR_ALL_PATTERNS) 
+      net_error[1] <- pr_res[[2]]
+      
+      # retrain network
+      if (net_error[1] > min_error_to_stop){ 
+        
+        
+        for(j in 1:no_of_pr_retrain_cycles) {
+          re_res <- snnsObject$learnAllPatternsFF(expandedLearnFuncParams)
+          net_error[j] <- re_res[[2]]
+          #if (j %% 100 == 0) print(c(retrain_loop_count, (format(j,digits=2)), net_error[j]))
+        }
+        
+        #plot(net_error, type="l")
+        
+      }
+      
+      if (net_error[j] <= max_error) {
+        retrain_loop_count <- retrain_loop_count + 1
+      } else { 
+        break 
+      }
+      
+      
+    }
+  }
+  
+#-----------------------------------------------------
+
   if(computeError)
     result$IterativeFitError <- errorTrain
  
@@ -171,4 +252,4 @@ SnnsR__train <- function(snnsObject, inputsTrain, targetsTrain=NULL,
   }
   
   result
-}
\ No newline at end of file
+}
